@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 """CCURE Update class file."""
 import csv
-import datetime
 import json
+import logging
 
 
 class Update:
@@ -70,6 +71,7 @@ class Update:
             "WorkerType",
             "OrgUnit",
             "Desk",
+            "EHSBasicTraining",
             "Parking",
             "Status",
             "ActivationDateTime",
@@ -77,6 +79,7 @@ class Update:
         ]
 
     def check_emplid_exceptions(self):
+        """Check for emplid exceptions."""
         if self.emplid_exceptions:
             print(f"\nCCURE-only Personnnel with a valid EMPLID [{len(self.emplid_exceptions)}]:")
         for p in sorted(self.emplid_exceptions, key=lambda x: x["first_name"] + x["last_name"]):
@@ -85,7 +88,7 @@ class Update:
             first_name = p["first_name"]
             last_name = p["last_name"]
             personnel_type_name = p["personnel_type_name"]
-            title = p["title"]
+            # title = p["title"]
             print(f" * {oid} {first_name} {last_name} [{personnel_type_name}] with emplid {emplid}")
 
     def check_matched_people(self, matched):
@@ -177,7 +180,7 @@ class Update:
     def get_credentials_dict(self):
         """Return a dict of Credentials."""
         if self.credentials:
-            return credentials
+            return self.credentials
         credentials = {}
         for c in self.get_credentials():
             cid = c["id"]
@@ -210,7 +213,7 @@ class Update:
                 "home_institution": row["Text8"],
                 "department_name": row["Text9"],
                 "supervisor_name": row["Text10"],
-                "text11": row["Text11"],
+                "ehs_basic_training": row["Text11"],
                 "text12": row["Text12"],
                 "text13": row["Text13"],
                 "legal_name": row["Text14"],
@@ -338,7 +341,6 @@ class Update:
             worker_sub_type = p["worker_sub_type"]
             p["personnel_type_name"] = worker_sub_type if worker_sub_type in personnel_type_names else "None"
             p["pid"] = ""
-            p["text11"] = ""
             p["text12"] = ""
             p["text13"] = ""
             p["text15"] = ""
@@ -414,14 +416,11 @@ class Update:
                 }
                 if output:
                     entries.append(card)
-
-                if output:
                     card_id = c['id']
                     emplid = p["emplid"]
                     first_name = p["first_name"]
                     last_name = p["last_name"]
                     personnel_id = c["personnel_id"]
-
                     print(f"\n{card_id} {first_name} {last_name} [{personnel_id} - {emplid}]:")
                     print("\n".join(output))
 
@@ -457,6 +456,7 @@ class Update:
             "WorkerType": p["worker_type"],
             "OrgUnit": p["org_unit"],
             "Desk": p["desk"],
+            "EHSBasicTraining": p["ehs_basic_training"],
             "Parking": p["parking"],
             "Status": p["status"],
             "ActivationDateTime": p["activation_datetime"],
@@ -493,14 +493,16 @@ class Update:
         csvwriter.writeheader()
 
         for card in entries:
+            card_id = card["ObjectID"]
             try:
                 csvwriter.writerow(card)
             except Exception as err:
-                print(f"ERROR Writing credential: {emplid} [{err}]")
-                print(person)
+                print(f"ERROR Writing credential: {card_id} [{err}]")
+                print(card)
 
         # close the csv file
         csvfile.close()
+
     def write_newpersonnel(self, newpersonnel):
         """Write out the newpersonnel.csv file."""
         entries = self.prepare_newpersonnel(newpersonnel)
@@ -549,6 +551,7 @@ class Update:
         """Update Personnel and Credentials from People."""
         # create dicts of people by emplid and pid
         emplids = self.prepare_people(people)
+        print(f"EMPLIDs: {len(emplids)}")
 
         # check for missing personnel types
         if self.missing_personnel_types:
@@ -559,7 +562,7 @@ class Update:
         personnel = self.get_personnel_dict()
 
         # get credentials from CCURE
-        credentials = self.get_credentials_dict()
+        self.get_credentials_dict()
 
         # organize personnel by CCURE-only or Workday
         ccure_people, workday_people = self.organize_personnel(personnel)
